@@ -183,6 +183,10 @@ def _create_sportsreference_player_model(
                 logging.warning("Failed to find birth address: %s", str(exc))
         if "height" in jsonld:
             height_ft_inches = jsonld["height"]["value"].split()[0].split("-")
+            if len(height_ft_inches) == 1:
+                height_ft_inches = [
+                    x.replace('"', "") for x in height_ft_inches.split("'")
+                ]
             height = (float(height_ft_inches[0]) * 30.48) + (
                 float(height_ft_inches[1]) * 2.54
             )
